
/* ----------------------------------------------------------------
 * string conversion algorithms:
 * used jd.h
 * ----------------------------------------------------------------
 */

char *
xJDtoGregorianString( jd )
double jd;
{
  int year, month, day;
  static char buf[50];

  xJDtoGregorianCalendar( jd, &year, &month, &day ); 
  sprintf( buf, "% d% 2d% 2d", year, month, day );

  return buf;

}

char *
xJDtoJulianString( jd )
double jd;
{
  int year, month, day;
  static char buf[50];

  JDtoJulianCalendar( jdnoon(jd), &year, &month, &day ); 
  sprintf( buf, "% d% 2d% 2d", year, month, day );

  return buf;

}


char *
xJDtoString( jd )
double jd;
{
  if (gregorian) return xJDtoGregorianString( jd );
  else           return xJDtoJulianString( jd );
}


/* ----------------------------------------------------------------
 * these routines let the calling sequence supply the storage space
 *    in which to put the result,
 *    and supply the format string which specifies how to format the result
 * (that way, the calling routine can worry about when the string gets over-written,
 *    and one routine can provide answers formatted to a variety of calling sequences)
 * inputs
 *    the julian day number, as a double-float
 *    pointer to the buffer to hold the answer
 *    pointer to the format-string with which to format the answer
 * outputs
 *    pointer to the answer (which happens to be the same as the 2nd input)
 * side effects
 *    writes to the buffer 'buf', indicated on input
 * ----------------------------------------------------------------
 */

char *
xGregorianCalendarDate( jd, buf, format )
double jd;
char *buf;
char *format;
{
  int year, month, day;
  int hours, minutes, seconds;
  float fday;	      /* fraction of day */ 

  fday = jd - floor(jd-0.5) - 0.5; 
  if (fday == 1.) fday = 0.; 
  
  hours = floor( fday * 24. );
  minutes = floor(  (fday - hours/24.) * 1440.  );
  seconds = floor(  (fday - hours/24. - minutes/1440.) * 86400.  );
  
  xJDtoGregorianCalendar( jd, &year, &month, &day ); 
  sprintf( buf, format, year, month, day, hours, minutes, seconds );

  return buf;

}

/* ----------------------------------------------------------------
 * the same, but for Julian calendar
 * ----------------------------------------------------------------
 */


char *
xJulianCalendarDate( jd, buf, format )
double jd;
char *buf;
char *format;
{
  int year, month, day;
  int hours, minutes, seconds;
  float fday;	      /* fraction of day */ 

  fday = jd - floor(jd-0.5) - 0.5; 
  if (fday == 1.) fday = 0.; 
  
  hours = floor( fday * 24. );
  minutes = floor(  (fday - hours/24.) * 1440.  );
  seconds = floor(  (fday - hours/24. - minutes/1440.) * 86400.  );
  
  xJDtoJulianCalendar( jd, &year, &month, &day ); 
  sprintf( buf, format, year, month, day, hours, minutes, seconds );

  return buf;

}


/* ----------------------------------------------------------------
 * the same, but for whichever calendar applies,
 * according to the global variable 'gregorian'
 */


char *
xCalendarDate( jd, buf, format )
double jd;
char *buf;
char *format;
{
  if (gregorian) return xGregorianCalendarDate( jd, buf, format );
  else		 return xJulianCalendarDate(    jd, buf, format );
}

char *
CalendarDate( jd, buf, format )
long jd;
char *buf;
char *format;
{
  double xjd;

  xjd = (double) jdnoon( (double) jd ); 
  if (gregorian) return xGregorianCalendarDate( xjd, buf, format );
  else		 return    xJulianCalendarDate( xjd, buf, format );

}

